AddressMapMemberships class final

Typed helper for the memberships block of cloudflare_address_map (derived from provider schema).

Annotations
  • @immutable

Constructors

AddressMapMemberships({TfArg<String>? identifier, AddressMapKind? kind})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → TfArg<String>?
final
kind → AddressMapKind?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited