AiSearchInstanceWebCrawler class final
Typed helper for the source_params.web_crawler block of
cloudflare_ai_search_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- AiSearchInstanceWebCrawler({AiSearchInstanceParseType? parseType, AiSearchInstanceDiscoverOptions? discoverOptions, AiSearchInstanceParseOptions? parseOptions})
-
const
Properties
- discoverOptions → AiSearchInstanceDiscoverOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parseOptions → AiSearchInstanceParseOptions?
-
final
- parseType → AiSearchInstanceParseType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited