CustomSslBundleMethod extension type
Custom Ssl Bundle enum for bundle_method.
Constructors
-
CustomSslBundleMethod.arg(TfArg<
String> arg) -
const
- CustomSslBundleMethod.expression(String template)
- CustomSslBundleMethod.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- force → const CustomSslBundleMethod
- optimal → const CustomSslBundleMethod
- ubiquitous → const CustomSslBundleMethod
-
values
→ const List<
CustomSslBundleMethod>