DataCustomOriginTrustStoreFilter class final

Typed helper for the filter block of cloudflare_custom_origin_trust_store (derived from provider schema).

Annotations
  • @immutable

Constructors

DataCustomOriginTrustStoreFilter({TfArg<num>? limit, TfArg<num>? offset})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → TfArg<num>?
final
offset → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited