DataOrganizationsContaining class final
Typed helper for the containing block of
cloudflare_organizations (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataOrganizationsContaining({TfArg<
String> ? account, TfArg<String> ? organization, TfArg<String> ? user}) -
const
Properties
-
account
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
organization
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
user
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited