DataSecretsStoreSecretFilter class final

Typed helper for the filter block of cloudflare_secrets_store_secret (derived from provider schema).

Annotations
  • @immutable

Constructors

DataSecretsStoreSecretFilter({TfArg<String>? direction, TfArg<String>? order, TfArg<List<Object?>>? scopes, TfArg<String>? search})
const

Properties

direction → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
order → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes → TfArg<List<Object?>>?
final
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited