DataWorkersCustomDomainFilter class final

Typed helper for the filter block of cloudflare_workers_custom_domain (derived from provider schema).

Annotations
  • @immutable

Constructors

DataWorkersCustomDomainFilter({TfArg<String>? environment, TfArg<String>? hostname, TfArg<String>? service, RefTo<CloudflareZone>? zoneId, TfArg<String>? zoneName})
const

Properties

environment → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
hostname → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → TfArg<String>?
final
zoneId → RefTo<CloudflareZone>?
final
zoneName → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited