DataWorkflowFilter class final

Typed helper for the filter block of cloudflare_workflow (derived from provider schema).

Annotations
  • @immutable

Constructors

DataWorkflowFilter({TfArg<String>? search})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited