DataZoneLockdownFilter class final

Typed helper for the filter block of cloudflare_zone_lockdown (derived from provider schema).

Annotations
  • @immutable

Constructors

DataZoneLockdownFilter({TfArg<String>? createdOn, TfArg<String>? description, TfArg<String>? descriptionSearch, TfArg<String>? ip, TfArg<String>? ipRangeSearch, TfArg<String>? ipSearch, TfArg<String>? modifiedOn, TfArg<num>? priority, TfArg<String>? uriSearch})
const

Properties

createdOn → TfArg<String>?
final
description → TfArg<String>?
final
descriptionSearch → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
ip → TfArg<String>?
final
ipRangeSearch → TfArg<String>?
final
ipSearch → TfArg<String>?
final
modifiedOn → TfArg<String>?
final
priority → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uriSearch → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited