FirewallRuleAction class final

Typed helper for the action block of cloudflare_firewall_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

FirewallRuleAction({TfArg<String>? mode, TfArg<num>? timeout, FirewallRuleActionResponse? response})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mode → TfArg<String>?
final
response FirewallRuleActionResponse?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout → TfArg<num>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited