LoadBalancerAdaptiveRouting class final
Typed helper for the adaptive_routing block of
cloudflare_load_balancer (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
LoadBalancerAdaptiveRouting({TfArg<
bool> ? failoverAcrossPools}) -
const
Properties
-
failoverAcrossPools
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited