LoadBalancerMonitorGroupMembers class final

Typed helper for the members block of cloudflare_load_balancer_monitor_group (derived from provider schema).

Annotations
  • @immutable

Constructors

LoadBalancerMonitorGroupMembers({required TfArg<bool> enabled, required TfArg<String> monitorId, required TfArg<bool> monitoringOnly, required TfArg<bool> mustBeHealthy})
const

Properties

enabled → TfArg<bool>
final
hashCode int
The hash code for this object.
no setterinherited
monitorId → TfArg<String>
final
monitoringOnly → TfArg<bool>
final
mustBeHealthy → TfArg<bool>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited