LoadBalancerPoolHeader class final

Typed helper for the origins.header block of cloudflare_load_balancer_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

LoadBalancerPoolHeader({TfArg<List<String>>? host})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited