LoadBalancerPoolOrigins class final

Typed helper for the origins block of cloudflare_load_balancer_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

LoadBalancerPoolOrigins({TfArg<String>? address, TfArg<bool>? enabled, TfArg<bool>? flattenCname, TfArg<String>? name, TfArg<num>? port, TfArg<String>? virtualNetworkId, TfArg<num>? weight, LoadBalancerPoolOriginsHeader? header})
const

Properties

address → TfArg<String>?
final
enabled → TfArg<bool>?
final
flattenCname → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
final
name → TfArg<String>?
final
port → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
virtualNetworkId → TfArg<String>?
final
weight → TfArg<num>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited