LoadBalancerRules class final

Typed helper for the rules block of cloudflare_load_balancer (derived from provider schema).

Annotations
  • @immutable

Constructors

LoadBalancerRules({TfArg<String>? condition, TfArg<bool>? disabled, TfArg<String>? name, TfArg<num>? priority, TfArg<bool>? terminates, LoadBalancerRulesFixedResponse? fixedResponse, LoadBalancerRulesOverrides? overrides})
const

Properties

condition → TfArg<String>?
final
disabled → TfArg<bool>?
final
fixedResponse LoadBalancerRulesFixedResponse?
final
hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
overrides LoadBalancerRulesOverrides?
final
priority → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminates → TfArg<bool>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited