LoadBalancerRulesOverrides class final
Typed helper for the rules.overrides block of
cloudflare_load_balancer (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
LoadBalancerRulesOverrides({TfArg<
Map< ? countryPools, TfArg<String, dynamic> >List< ? defaultPools, TfArg<Object?> >String> ? fallbackPool, TfArg<Map< ? popPools, TfArg<String, dynamic> >Map< ? regionPools, TfArg<String, dynamic> >String> ? sessionAffinity, TfArg<num> ? sessionAffinityTtl, TfArg<String> ? steeringPolicy, TfArg<num> ? ttl, LoadBalancerRulesOverridesAdaptiveRouting? adaptiveRouting, LoadBalancerRulesOverridesLocationStrategy? locationStrategy, LoadBalancerRulesOverridesRandomSteering? randomSteering, LoadBalancerRulesOverridesSessionAffinityAttributes? sessionAffinityAttributes}) -
const
Properties
- adaptiveRouting → LoadBalancerRulesOverridesAdaptiveRouting?
-
final
-
countryPools
→ TfArg<
Map< ?String, dynamic> > -
final
-
defaultPools
→ TfArg<
List< ?Object?> > -
final
-
fallbackPool
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationStrategy → LoadBalancerRulesOverridesLocationStrategy?
-
final
-
popPools
→ TfArg<
Map< ?String, dynamic> > -
final
- randomSteering → LoadBalancerRulesOverridesRandomSteering?
-
final
-
regionPools
→ TfArg<
Map< ?String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessionAffinity
→ TfArg<
String> ? -
final
- sessionAffinityAttributes → LoadBalancerRulesOverridesSessionAffinityAttributes?
-
final
-
sessionAffinityTtl
→ TfArg<
num> ? -
final
-
steeringPolicy
→ TfArg<
String> ? -
final
-
ttl
→ TfArg<
num> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited