MagicNetworkMonitoringConfigurationWarpDevices class final

Typed helper for the warp_devices block of cloudflare_magic_network_monitoring_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

MagicNetworkMonitoringConfigurationWarpDevices({required TfArg<String> id, required TfArg<String> name, required TfArg<String> routerIp})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → TfArg<String>
final
name → TfArg<String>
final
routerIp → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited