MagicTransitSiteLanStaticAddressing class final

Typed helper for the static_addressing block of cloudflare_magic_transit_site_lan (derived from provider schema).

Annotations
  • @immutable

Constructors

MagicTransitSiteLanStaticAddressing({required TfArg<String> address, TfArg<String>? secondaryAddress, TfArg<String>? virtualAddress, MagicTransitSiteLanStaticAddressingDhcpRelay? dhcpRelay, MagicTransitSiteLanStaticAddressingDhcpServer? dhcpServer})
const

Properties

address → TfArg<String>
final
dhcpRelay MagicTransitSiteLanStaticAddressingDhcpRelay?
final
dhcpServer MagicTransitSiteLanStaticAddressingDhcpServer?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryAddress → TfArg<String>?
final
virtualAddress → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited