PageRuleActionsCacheKeyFieldsHeader class final

Typed helper for the actions.cache_key_fields.header block of cloudflare_page_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

PageRuleActionsCacheKeyFieldsHeader({TfArg<List<Object?>>? checkPresence, TfArg<List<Object?>>? exclude, TfArg<List<Object?>>? include})
const

Properties

checkPresence → TfArg<List<Object?>>?
final
exclude → TfArg<List<Object?>>?
final
hashCode int
The hash code for this object.
no setterinherited
include → TfArg<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited