PagesProjectConfig class final

Typed helper for the source.config block of cloudflare_pages_project (derived from provider schema).

Annotations
  • @immutable

Constructors

PagesProjectConfig({TfArg<bool>? deploymentsEnabled, TfArg<String>? owner, TfArg<String>? ownerId, TfArg<List<String>>? pathExcludes, TfArg<List<String>>? pathIncludes, TfArg<bool>? prCommentsEnabled, TfArg<List<String>>? previewBranchExcludes, TfArg<List<String>>? previewBranchIncludes, PagesProjectPreviewDeploymentSetting? previewDeploymentSetting, TfArg<String>? productionBranch, TfArg<bool>? productionDeploymentsEnabled, TfArg<String>? repoId, TfArg<String>? repoName})
const

Properties

deploymentsEnabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
owner → TfArg<String>?
final
ownerId → TfArg<String>?
final
pathExcludes → TfArg<List<String>>?
final
pathIncludes → TfArg<List<String>>?
final
prCommentsEnabled → TfArg<bool>?
final
previewBranchExcludes → TfArg<List<String>>?
final
previewBranchIncludes → TfArg<List<String>>?
final
previewDeploymentSetting → PagesProjectPreviewDeploymentSetting?
final
productionBranch → TfArg<String>?
final
productionDeploymentsEnabled → TfArg<bool>?
final
repoId → TfArg<String>?
final
repoName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited