PagesProjectDeploymentConfigs class final
Typed helper for the deployment_configs block of
cloudflare_pages_project (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- PagesProjectDeploymentConfigs({PagesProjectDeploymentConfigsPreview? preview, PagesProjectDeploymentConfigsProduction? production})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- preview → PagesProjectDeploymentConfigsPreview?
-
final
- production → PagesProjectDeploymentConfigsProduction?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited