PagesProjectSource class final

Typed helper for the source block of cloudflare_pages_project (derived from provider schema).

Annotations
  • @immutable

Constructors

PagesProjectSource({required TfArg<String> type, required PagesProjectSourceConfig config})
const

Properties

config PagesProjectSourceConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited