PipelineStreamFormat class final

Typed helper for the format block of cloudflare_pipeline_stream (derived from provider schema).

Annotations
  • @immutable

Constructors

PipelineStreamFormat({TfArg<String>? compression, TfArg<String>? decimalEncoding, TfArg<num>? rowGroupBytes, TfArg<String>? timestampFormat, required TfArg<String> type, TfArg<bool>? unstructured})
const

Properties

compression → TfArg<String>?
final
decimalEncoding → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
rowGroupBytes → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampFormat → TfArg<String>?
final
type → TfArg<String>
final
unstructured → TfArg<bool>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited