PrecursorEnforcementRules class final
Typed helper for the enforcement_rules block of
cloudflare_precursor (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
PrecursorEnforcementRules({TfArg<
String> ? description, TfArg<bool> ? enabled, required TfArg<String> expression, required PrecursorMode mode}) -
const
Properties
-
description
→ TfArg<
String> ? -
final
-
enabled
→ TfArg<
bool> ? -
final
-
expression
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → PrecursorMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited