QueueConsumerSettings class final

Typed helper for the settings block of cloudflare_queue_consumer (derived from provider schema).

Annotations
  • @immutable

Constructors

QueueConsumerSettings({TfArg<num>? batchSize, TfArg<num>? maxConcurrency, TfArg<num>? maxRetries, TfArg<num>? maxWaitTimeMs, TfArg<num>? retryDelay, TfArg<num>? visibilityTimeoutMs, List<QueueConsumerEmail>? email, List<QueueConsumerPagerduty>? pagerduty, List<QueueConsumerWebhooks>? webhooks})
const

Properties

batchSize → TfArg<num>?
final
email → List<QueueConsumerEmail>?
final
hashCode → int
The hash code for this object.
no setterinherited
maxConcurrency → TfArg<num>?
final
maxRetries → TfArg<num>?
final
maxWaitTimeMs → TfArg<num>?
final
pagerduty → List<QueueConsumerPagerduty>?
final
retryDelay → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibilityTimeoutMs → TfArg<num>?
final
webhooks → List<QueueConsumerWebhooks>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited