RateLimitActionResponse class final

Typed helper for the action.response block of cloudflare_rate_limit (derived from provider schema).

Annotations
  • @immutable

Constructors

RateLimitActionResponse({TfArg<String>? body, TfArg<String>? contentType})
const

Properties

body → TfArg<String>?
final
contentType → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited