RulesetMatchStatusCodeRange class final

The RulesetMatch.statusCodeRange choice: sets status_code_range.

Inheritance

Constructors

RulesetMatchStatusCodeRange(RulesetStatusCodeRange statusCodeRange)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCodeRange → RulesetStatusCodeRange
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited