RulesetQueryStringInclude class final
The RulesetQueryString.include choice: sets include.
- Inheritance
-
- Object
- RulesetQueryString
- RulesetQueryStringInclude
Constructors
- RulesetQueryStringInclude(RulesetInclude include)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- include → RulesetInclude
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited