RulesetRulesActionParametersCacheKey class final

Typed helper for the rules.action_parameters.cache_key block of cloudflare_ruleset (derived from provider schema).

Annotations
  • @immutable

Constructors

RulesetRulesActionParametersCacheKey({TfArg<bool>? cacheByDeviceType, TfArg<bool>? cacheDeceptionArmor, TfArg<bool>? ignoreQueryStringsOrder, RulesetRulesActionParametersCacheKeyCustomKey? customKey})
const

Properties

cacheByDeviceType → TfArg<bool>?
final
cacheDeceptionArmor → TfArg<bool>?
final
customKey RulesetRulesActionParametersCacheKeyCustomKey?
final
hashCode int
The hash code for this object.
no setterinherited
ignoreQueryStringsOrder → TfArg<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited