RulesetRulesActionParametersCacheKeyCustomKeyCookie class final

Typed helper for the rules.action_parameters.cache_key.custom_key.cookie block of cloudflare_ruleset (derived from provider schema).

Annotations
  • @immutable

Constructors

RulesetRulesActionParametersCacheKeyCustomKeyCookie({TfArg<List<Object?>>? checkPresence, TfArg<List<Object?>>? include})
const

Properties

checkPresence → TfArg<List<Object?>>?
final
hashCode int
The hash code for this object.
no setterinherited
include → TfArg<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited