TokenValidationConfigCredentials class final

Typed helper for the credentials block of cloudflare_token_validation_config (derived from provider schema).

Annotations
  • @immutable

Constructors

TokenValidationConfigCredentials({required List<TokenValidationConfigKeys> keys})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keys → List<TokenValidationConfigKeys>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited