WorkerVersionConfig class final

Typed helper for the assets.config block of cloudflare_worker_version (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkerVersionConfig({TfArg<String>? basePath, WorkerVersionHtmlHandling? htmlHandling, WorkerVersionNotFoundHandling? notFoundHandling, TfArg<Object?>? runWorkerFirst})
const

Properties

basePath → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
htmlHandling → WorkerVersionHtmlHandling?
final
notFoundHandling → WorkerVersionNotFoundHandling?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runWorkerFirst → TfArg<Object?>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited