WorkerVersionWorker class final

Typed helper for the bindings.outbound.worker block of cloudflare_worker_version (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkerVersionWorker({TfArg<String>? entrypoint, TfArg<String>? environment, TfArg<String>? service})
const

Properties

entrypoint → TfArg<String>?
final
environment → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited