WorkersScriptAssets class final

Typed helper for the assets block of cloudflare_workers_script (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkersScriptAssets({WorkersScriptSource? source, WorkersScriptConfig? config})
const

Properties

config → WorkersScriptConfig?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → WorkersScriptSource?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited