WorkersScriptPackageDependencies class final

Typed helper for the package_dependencies block of cloudflare_workers_script (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkersScriptPackageDependencies({required TfArg<String> installedVersion, required TfArg<String> name, required TfArg<String> packageJsonVersion})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
installedVersion → TfArg<String>
final
name → TfArg<String>
final
packageJsonVersion → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited