WorkersScriptSourceDirectory class final

The WorkersScriptSource.directory choice: sets directory.

Inheritance

Constructors

WorkersScriptSourceDirectory(TfArg<String> directory)
const

Properties

directory → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited