WorkersScriptWorker class final

Typed helper for the bindings.outbound.worker block of cloudflare_workers_script (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkersScriptWorker({TfArg<String>? environment, TfArg<String>? service})
const

Properties

environment → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited