ZeroTrustAccessApplicationOauthConfigurationDynamicClientRegistration class final

Typed helper for the oauth_configuration.dynamic_client_registration block of cloudflare_zero_trust_access_application (derived from provider schema).

Annotations
  • @immutable

Constructors

ZeroTrustAccessApplicationOauthConfigurationDynamicClientRegistration({TfArg<bool>? allowAnyOnLocalhost, TfArg<bool>? allowAnyOnLoopback, TfArg<List<Object?>>? allowedUris, TfArg<bool>? enabled})
const

Properties

allowAnyOnLocalhost → TfArg<bool>?
final
allowAnyOnLoopback → TfArg<bool>?
final
allowedUris → TfArg<List<Object?>>?
final
enabled → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited