ZeroTrustAccessApplicationSaasAppCustomAttributesSource class final
Typed helper for the saas_app.custom_attributes.source block of
cloudflare_zero_trust_access_application (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ZeroTrustAccessApplicationSaasAppCustomAttributesSource({TfArg<
String> ? name, List<ZeroTrustAccessApplicationSaasAppCustomAttributesSourceNameByIdp> ? nameByIdp}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> ? -
final
-
nameByIdp
→ List<
ZeroTrustAccessApplicationSaasAppCustomAttributesSourceNameByIdp> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited