ZeroTrustAccessIdentityProviderHeaderAttributes class final

Typed helper for the config.header_attributes block of cloudflare_zero_trust_access_identity_provider (derived from provider schema).

Annotations
  • @immutable

Constructors

ZeroTrustAccessIdentityProviderHeaderAttributes({TfArg<String>? attributeName, TfArg<String>? headerName})
const

Properties

attributeName → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited