ZoneCacheVariantsValue class final

Typed helper for the value block of cloudflare_zone_cache_variants (derived from provider schema).

Annotations
  • @immutable

Constructors

ZoneCacheVariantsValue({TfArg<List<Object?>>? avif, TfArg<List<Object?>>? bmp, TfArg<List<Object?>>? gif, TfArg<List<Object?>>? jp2, TfArg<List<Object?>>? jpeg, TfArg<List<Object?>>? jpg, TfArg<List<Object?>>? jpg2, TfArg<List<Object?>>? png, TfArg<List<Object?>>? tif, TfArg<List<Object?>>? tiff, TfArg<List<Object?>>? webp})
const

Properties

avif → TfArg<List<Object?>>?
final
bmp → TfArg<List<Object?>>?
final
gif → TfArg<List<Object?>>?
final
hashCode int
The hash code for this object.
no setterinherited
jp2 → TfArg<List<Object?>>?
final
jpeg → TfArg<List<Object?>>?
final
jpg → TfArg<List<Object?>>?
final
jpg2 → TfArg<List<Object?>>?
final
png → TfArg<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tif → TfArg<List<Object?>>?
final
tiff → TfArg<List<Object?>>?
final
webp → TfArg<List<Object?>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited