AiGatewayDynamicRoutingOutputs class final
Typed helper for the elements.outputs block of
cloudflare_ai_gateway_dynamic_routing (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AiGatewayDynamicRoutingOutputs({TfArg<
String> ? elementId, AiGatewayDynamicRoutingFallback? fallback, AiGatewayDynamicRoutingFalse? falseCase, AiGatewayDynamicRoutingNext? next, AiGatewayDynamicRoutingOutputsSuccess? success, AiGatewayDynamicRoutingTrue? trueCase}) -
const
Properties
-
elementId
→ TfArg<
String> ? -
final
- fallback → AiGatewayDynamicRoutingFallback?
-
final
- falseCase → AiGatewayDynamicRoutingFalse?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- next → AiGatewayDynamicRoutingNext?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → AiGatewayDynamicRoutingOutputsSuccess?
-
final
- trueCase → AiGatewayDynamicRoutingTrue?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited