ListRedirect class final
Typed helper for the items.redirect block of
cloudflare_list (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includeSubdomains
→ TfArg<
bool> ? -
final
-
preservePathSuffix
→ TfArg<
bool> ? -
final
-
preserveQueryString
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceUrl
→ TfArg<
String> -
final
-
statusCode
→ TfArg<
num> ? -
final
-
subpathMatching
→ TfArg<
bool> ? -
final
-
targetUrl
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited