LoadBalancerRandomSteering class final
Typed helper for the random_steering block of
cloudflare_load_balancer (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
LoadBalancerRandomSteering({TfArg<
num> ? defaultWeight, TfArg<Map< ? poolWeights})String, num> > -
const
Properties
-
defaultWeight
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
poolWeights
→ TfArg<
Map< ?String, num> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited