LoadBalancerRulesFixedResponse class final
Typed helper for the rules.fixed_response block of
cloudflare_load_balancer (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
LoadBalancerRulesFixedResponse({TfArg<
String> ? contentType, TfArg<String> ? location, TfArg<String> ? messageBody, TfArg<num> ? statusCode}) -
const
Properties
-
contentType
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
location
→ TfArg<
String> ? -
final
-
messageBody
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statusCode
→ TfArg<
num> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited