LoadBalancerSessionAffinityAttributes class final
Typed helper for the session_affinity_attributes block of
cloudflare_load_balancer (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
drainDuration
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ TfArg<
List< ?Object?> > -
final
-
requireAllHeaders
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
samesite
→ TfArg<
String> ? -
final
-
secure
→ TfArg<
String> ? -
final
-
zeroDowntimeFailover
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited