RulesetCacheReserve class final
Typed helper for the rules.action_parameters.cache_reserve block of
cloudflare_ruleset (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
RulesetCacheReserve({required TfArg<
bool> eligible, TfArg<num> ? minimumFileSize}) -
const
Properties
-
eligible
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
minimumFileSize
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited