VulnerabilityScannerTargetEnvironmentTarget class final
Typed helper for the target block of
cloudflare_vulnerability_scanner_target_environment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
VulnerabilityScannerTargetEnvironmentTarget({required VulnerabilityScannerTargetEnvironmentType type, required TfArg<
String> zoneTag}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → VulnerabilityScannerTargetEnvironmentType
-
final
-
zoneTag
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited