WorkersScriptBindingsSimple class final
Typed helper for the bindings.simple block of
cloudflare_workers_script (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
WorkersScriptBindingsSimple({required TfArg<
num> limit, TfArg<num> ? mitigationTimeout, required TfArg<num> period}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
limit
→ TfArg<
num> -
final
-
mitigationTimeout
→ TfArg<
num> ? -
final
-
period
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited