ZoneCacheVariantsValue class final

Typed helper for the value block of cloudflare_zone_cache_variants (derived from provider schema).

Annotations
  • @immutable

Constructors

ZoneCacheVariantsValue({TfArg<List<String>>? avif, TfArg<List<String>>? bmp, TfArg<List<String>>? gif, TfArg<List<String>>? jp2, TfArg<List<String>>? jpeg, TfArg<List<String>>? jpg, TfArg<List<String>>? jpg2, TfArg<List<String>>? png, TfArg<List<String>>? tif, TfArg<List<String>>? tiff, TfArg<List<String>>? webp})
const

Properties

avif → TfArg<List<String>>?
final
bmp → TfArg<List<String>>?
final
gif → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
jp2 → TfArg<List<String>>?
final
jpeg → TfArg<List<String>>?
final
jpg → TfArg<List<String>>?
final
jpg2 → TfArg<List<String>>?
final
png → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tif → TfArg<List<String>>?
final
tiff → TfArg<List<String>>?
final
webp → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited